sPCAplot <- function( sp, coords ) {
  library(rgdal)
  source("./scripts/filled.contour3.R")
  source("./scripts/filled.legend.R")
  
  YOSEbndry <- readOGR(paste0(getwd(), "/GIS"), "YOSEbndry")
  YOSEbndry <- spTransform(YOSEbndry, CRS("+init=epsg:26911"))
  
  
  x = coords$E
  y = coords$N
  
  plot.new()
  myPal <- colorRampPalette(c("firebrick2", "white", "lightslateblue"))
  
  par(new = "TRUE",plt = c(0.1,0.4,0.55,0.9),las = 1,cex.axis = 1)
  temp <- interp(x, y, sp$ls[,1], duplicate="mean")
  annot <- function(){title("sPCA 1", line=0.25, cex.main=1); points(x,y,pch=19,cex=.3)}
  filled.contour3(temp, color.pal=myPal, nlev=50, xlab = "",ylab = "",
                  plot.title=annot(), zlim=c(-10, 13.1), ylim=range(4151598, 4230672),
                  xlim=range(245268.6, 307576.1), plot.axes={axis(1,padj=-4.2,seq(250000,
                                                                                  300000, by=10000), tck=-0.02, cex.axis=0.5, labels=seq(25, 30, by=1));
                    axis(2,seq(4160000,4220000, by=10000),tck=-0.02, cex.axis=0.5, hadj=0,
                         labels=seq(416, 422, by=1));plot(YOSEbndry, add=T)})
  mtext("(a)", side=2, padj=-8, line=1, cex=1.3, font=2)
  par(new = "TRUE",plt = c(0.32,0.4,0.555,0.615),las = 1,cex.axis = 1)
  barplot(sp$eig[1:16], col=c("black",rep(NA,15)),
          width=0.25,space=0,xlim=c(0,4),ylim=c(0,50), axes=F, ann=F)
  mtext("EigenV", side=3, line=-0.4, cex=0.7, font=2)
  
  par(new = "TRUE",plt = c(0.5,0.8,0.55,0.9),las = 1,cex.axis = 1)
  temp <- interp(x, y, sp$li[,2], duplicate="mean")
  annot <- function(){title("sPCA 2", line=0.25, cex.main=1); points(x,y,pch=19,cex=.3)}
  filled.contour3(temp, color.pal=myPal, nlev=50, xlab = "",ylab = "",
                  plot.title=annot(), zlim=c(-10, 13), ylim=range(4151598, 4230672),
                  xlim=range(245268.6, 307576.1), plot.axes={axis(1,padj=-4.2,seq(250000,
                                                                                  300000, by=10000), tck=-0.02, cex.axis=0.5, labels=seq(25, 30, by=1));
                    axis(2,seq(4160000,4220000, by=10000),tck=-0.02, cex.axis=0.5, hadj=0,
                         labels=seq(416, 422, by=1));plot(YOSEbndry, add=T)})
  mtext("(b)", side=2, padj=-8, line=1, cex=1.3, font=2)
  par(new = "TRUE",plt = c(0.72,0.8,0.555,0.615),las = 1,cex.axis = 1)
  barplot(sp$eig[1:16], col=c(NA,"black",rep(NA,14)),
          width=0.25,space=0,xlim=c(0,4),ylim=c(0,50), axes=F, ann=F)
  mtext("EigenV", side=3, line=-0.4, cex=0.7, font=2)
  
  par(new = "TRUE",plt = c(0.1,0.4,0.1,0.45),las = 1,cex.axis = 1)
  temp <- interp(x, y, -sp$li[,3], duplicate="mean")
  annot <- function(){title("sPCA 3", line=0.25, cex.main=1); points(x,y,pch=19,cex=.3)}
  filled.contour3(temp, color.pal=myPal, nlev=50, xlab = "",ylab = "",
                  plot.title=annot(), zlim=c(-10, 13), ylim=range(4151598, 4230672),
                  xlim=range(245268.6, 307576.1), plot.axes={axis(1,padj=-4.2,seq(250000,
                                                                                  300000, by=10000), tck=-0.02, cex.axis=0.5, labels=seq(25, 30, by=1));
                    axis(2,seq(4160000,4220000, by=10000),tck=-0.02, cex.axis=0.5, hadj=0,
                         labels=seq(416, 422, by=1));plot(YOSEbndry, add=T)})
  mtext("(c)", side=2, padj=-8, line=1, cex=1.3, font=2)
  par(new = "TRUE",plt = c(0.32,0.4,0.105,0.165),las = 1,cex.axis = 1)
  barplot(sp$eig[1:16], col=c(NA,NA,"black",rep(NA,13)),
          width=0.25,space=0,xlim=c(0,4),ylim=c(0,50), axes=F, ann=F)
  mtext("EigenV", side=3, line=-0.4, cex=0.7, font=2)
  
  par(new = "TRUE",plt = c(0.5,0.8,0.1,0.45),las = 1,cex.axis = 1)
  annot <- function(){title("First Three sPCAs", line=0.25, cex.main=1)}
  for (n in temp[[3]]) temp[[3]][n] <- NA
  filled.contour3(temp, color.pal=myPal, nlev=50, xlab = "",ylab = "",
                  plot.title=annot(), zlim=c(-10, 13), ylim=range(4151598, 4230672),
                  xlim=range(245268.6, 307576.1), plot.axes={axis(1,padj=-4.2,seq(250000,
                                                                                  300000, by=10000), tck=-0.02, cex.axis=0.5, labels=seq(25, 30, by=1));
                    axis(2,seq(4160000,4220000, by=10000),tck=-0.02, cex.axis=0.5, hadj=0,
                         labels=seq(416, 422, by=1));plot(YOSEbndry, add=T)})
  mtext("(d)", side=2, padj=-8, line=1, cex=1.3, font=2)
  plot(YOSEbndry, add=T)
  sp_unique <- sp$li[!duplicated(sp$xy[1:2]),1:3]
  xy_unique <- sp$xy[!duplicated(sp$xy[1:2]),]
  newx <- jitter(xy_unique[,1], factor=1000, amount=1000)
  newy <- jitter(xy_unique[,2], factor=1000, amount=1000)
  newxy <- data.frame(newx,newy)
  colorplot(xy=newxy, X=sp_unique, cex=3, transp=T, add=T)
  par(new = "TRUE",plt = c(0.72,0.8,0.105,0.165),las = 1,cex.axis = 1)
  barplot(sp$eig[1:16], col=c(rep("black",3),rep(NA,13)),
          width=0.25,space=0,xlim=c(0,4),ylim=c(0,50), axes=F, ann=F)
  # axis(side = 2, pos = -0.05, seq(0,50,25))
  mtext("EigenV", side=3, line=-0.4, cex=0.7, font=2)
  
  
  xcoords <- unique(x)
  ycoords <- unique(y)
  #Add a legend:
  par(new = "TRUE",plt = c(0.85,0.9,0.20,0.80),las = 1,cex.axis = 1)
  filled.legend(temp,color = myPal, xlab = "", ylab = "",
                xlim = c(min(xintercepts),max(xintercepts)),ylim = c(min(slopes),
                                                                     max(slopes)), zlim=c(-10, 13), key.title="PC Score")
  
  #Add some figure labels
  par(xpd=NA,cex = 1.3)
  text(x = -16.7, y = 0, "UTM N", srt = 90,cex = 1, font=2)
  text(x = -8, y = -15.5, "UTM E", cex = 1, font=2)
  text(x = -8, y = 19.5, "Spatial PCA of YoToads in Yosemite NP", cex = 1.3, font=2)
  text(x = 0.5, y = 15, "PC\nScore", cex = 1.3, font=2)
}

